package ru.myitschool.work.api

import retrofit2.Response
import retrofit2.http.Body
import retrofit2.http.GET
import retrofit2.http.PATCH
import retrofit2.http.POST
import retrofit2.http.Path
import retrofit2.http.Query

interface ApiService {
    // Метод для аутентификации
    @GET("/api/auth") // Используем GET для аутентификации
    suspend fun authenticate(
        @Query("login") login: String, // Передаем логин как параметр запроса
        @Query("password") password: String // Передаем пароль как параметр запроса
    ): Response<UserAuthResponse> // Возвращаем JSON как объект UserAuthResponse

    // Другие методы...
    @GET("/api/{login}/info") // Получение информации о пользователе
    suspend fun getUserInfo(@Path("login") login: String): Response<Map<String, Any>>

    @GET("/api/employee/{login}") // Получение информации о сотруднике
    suspend fun getEmployeeInfo(@Path("login") login: String): Response<EmployeeData>

    @PATCH("/api/open") // Открыть дверь
    suspend fun openDoor(@Body request: OpenDoorRequest): Response<String>

    @POST("/api/employee/toggleAccess") // Метод для блокировки/разблокировки доступа
    suspend fun toggleAccess(@Body request: ToggleAccessRequest): Response<Unit>

    @GET("/api/workers") // Получить всех сотрудников
    suspend fun getAllWorkers(): Response<List<EmployeeData>>
}

// Модель данных для ответа аутентификации
data class UserAuthResponse(
    val role: String // Добавляем поле для роли
)

// Модель данных для информации о сотруднике
data class EmployeeData(
    val name: String,
    val position: String,
    val lastVisit: String
)

// Модель данных для запроса блокировки/разблокировки доступа
data class ToggleAccessRequest(
    val login: String, // Логин сотрудника
    val action: String // Действие: "block" или "unblock"
)

// Модель данных для запроса открытия двери
data class OpenDoorRequest(
    val login: String, // Логин сотрудника
    val value: Long // Код для открытия двери
)